@@ -7,7 +7,7 @@ use Carp ();
 use Capture::Tiny qw(capture);
 use File::Which ();
 
-our $VERSION = '0.021';
+our $VERSION = '0.03';
 
 sub new {
     my ($class, @args) = @_;
@@ -27,6 +27,13 @@ sub new {
     }, $class;
 }
 
+sub version {
+    my $self = shift;
+    my ($ret, $exit_status) = $self->_readpipe($self->{command}, 'version');
+    $ret =~ /^RRDtool (\d+)\.(\d+).(\d+)/;
+    return "$1.$2$3";  # like "1.47"
+}
+
 sub errstr { $_[0]->{rrderror} }
 
 sub create {
@@ -252,6 +259,14 @@ In contrast, RRDTool::Rawish has less dependencies and it's easy to install it.
 
 Creates a new instance of RRDTool::Rawish.
 
+=item $rrd->version()
+
+Returns rrdtool's version like "1.47".
+
+=item $rrd->errstr()
+
+Returns rrdtool's stderr string. If no error occurs, it returns empty string.
+
 =item $rrd->create($params, [\%opts])
 Returns exit status
 
